package javax.swing.border;

import java.awt.Insets;
import java.awt.Graphics;
import java.awt.Component;
import java.beans.ConstructorProperties;

public class CompoundBorder extends AbstractBorder
{
    protected Border outsideBorder;
    protected Border insideBorder;
    
    public CompoundBorder() {
        this.outsideBorder = null;
        this.insideBorder = null;
    }
    
    @ConstructorProperties({ "outsideBorder", "insideBorder" })
    public CompoundBorder(Border outsideBorder, Border insideBorder) {
        this.outsideBorder = outsideBorder;
        this.insideBorder = insideBorder;
    }
    
    @Override
    public boolean isBorderOpaque() {
        return (this.outsideBorder == null || this.outsideBorder.isBorderOpaque()) && (this.insideBorder == null || this.insideBorder.isBorderOpaque());
    }
    
    @Override
    public void paintBorder(Component component, Graphics graphics, int n, int n2, int n3, int n4) {
        if (this.outsideBorder != null) {
            this.outsideBorder.paintBorder(component, graphics, n, n2, n3, n4);
            Insets borderInsets = this.outsideBorder.getBorderInsets(component);
            n += borderInsets.left;
            n2 += borderInsets.top;
            n3 = n3 - borderInsets.right - borderInsets.left;
            n4 = n4 - borderInsets.bottom - borderInsets.top;
        }
        if (this.insideBorder != null) {
            this.insideBorder.paintBorder(component, graphics, n, n2, n3, n4);
        }
    }
    
    @Override
    public Insets getBorderInsets(Component component, Insets insets) {
        int n = 0;
        insets.bottom = n;
        insets.right = n;
        insets.left = n;
        insets.top = n;
        if (this.outsideBorder != null) {
            Insets borderInsets = this.outsideBorder.getBorderInsets(component);
            insets.top += borderInsets.top;
            insets.left += borderInsets.left;
            insets.right += borderInsets.right;
            insets.bottom += borderInsets.bottom;
        }
        if (this.insideBorder != null) {
            Insets borderInsets2 = this.insideBorder.getBorderInsets(component);
            insets.top += borderInsets2.top;
            insets.left += borderInsets2.left;
            insets.right += borderInsets2.right;
            insets.bottom += borderInsets2.bottom;
            return insets;
        }
        return insets;
    }
    
    public Border getOutsideBorder() {
        return this.outsideBorder;
    }
    
    public Border getInsideBorder() {
        return this.insideBorder;
    }
}
